@@ -66,11 +66,13 @@ KfindTabWidget::KfindTabWidget(const KURL & url,
     dirBox  = new QComboBox(TRUE, pages[0], "combo2");
     QLabel * lookinL = new QLabel(dirBox, i18n("&Look in:"), pages[0], "named");
     subdirsCb  = new QCheckBox(i18n("Include &subdirectories"), pages[0]);
+    caseSensCb  = new QCheckBox(i18n("&Case sensitive search"), pages[0]);
     browseB    = new QPushButton(i18n("&Browse..."), pages[0]);
 
     // Setup
 
     subdirsCb->setChecked(true);
+    caseSensCb->setChecked(true);
 
     nameBox->setDuplicatesEnabled(FALSE);
     dirBox->setDuplicatesEnabled(FALSE);
@@ -83,14 +85,17 @@ KfindTabWidget::KfindTabWidget(const KURL & url,
     QGridLayout *grid = new QGridLayout( pages[0], 3, 3,
 					 KDialog::marginHint(),
 					 KDialog::spacingHint() );
+    QBoxLayout *subgrid = new QHBoxLayout( -1 , "subgrid" );
     grid->addWidget( namedL, 0, 0 );
     grid->addMultiCellWidget( nameBox, 0, 0, 1, 2 );
     grid->addWidget( lookinL, 1, 0 );
     grid->addWidget( dirBox, 1, 1 );
     grid->addWidget( browseB, 1, 2);
-    grid->addWidget( subdirsCb, 2, 1);
     grid->setColStretch(1,1);
-
+    grid->addMultiCellLayout( subgrid, 2, 2, 1, 2 );
+    subgrid->addWidget( subdirsCb );
+    subgrid->addSpacing( KDialog::spacingHint() );
+    subgrid->addWidget( caseSensCb, 1 );
     // Signals
 
     connect( browseB, SIGNAL(clicked()),
@@ -117,7 +122,9 @@ KfindTabWidget::KfindTabWidget(const KURL & url,
     le[2]  = new QLineEdit(pages[1], "lineEdit3" );
     le[3]  = new QLineEdit(pages[1], "lineEdit4" );
 
-    // Setup
+    rb2[0]->setChecked(true);
+
+     // Setup
 
     le[0] ->setText(date2String(QDate(1980,1,1)));
     le[1] ->setText(date2String(QDate::currentDate()));
@@ -189,7 +196,7 @@ KfindTabWidget::KfindTabWidget(const KURL & url,
     QLabel * sizeL   =new QLabel(sizeBox,i18n("&Size is:"), pages[2],"size");
     sizeEdit=new QLineEdit(pages[2], "sizeEdit" );
     QLabel * kbL     =new QLabel(i18n("KB"), pages[2], "kb");
-    caseCb  =new QCheckBox(i18n("Case S&ensitive"), pages[2]);
+    caseContextCb  =new QCheckBox(i18n("Case S&ensitive (content)"), pages[2]);
 
     // Setup
 
@@ -238,7 +245,7 @@ KfindTabWidget::KfindTabWidget(const KURL & url,
     grid2->addWidget( sizeEdit, 2, 2 );
     grid2->addWidget( kbL, 2, 3 );
     grid2->addColSpacing(4, KDialog::spacingHint());
-    grid2->addWidget( caseCb, 2, 5 );
+    grid2->addWidget( caseContextCb, 2, 5 );
     grid2->setColStretch(6,1);
 
     addTab( pages[2], i18n(" Advanced ") );
@@ -378,7 +385,7 @@ void KfindTabWidget::setQuery(KQuery *query)
 
   query->setPath(KURL(dirBox->currentText()));
 
-  query->setRegExp(QRegExp(nameBox->currentText(), true, true));
+  query->setRegExp(QRegExp(nameBox->currentText(), caseSensCb->isChecked(), true));
 
   query->setRecursive(subdirsCb->isChecked());
 
@@ -439,7 +446,7 @@ void KfindTabWidget::setQuery(KQuery *query)
      query->setMimeType( QString::null );
   }
 
-  query->setContext(textEdit->text(), caseCb->isChecked());
+  query->setContext(textEdit->text(), caseContextCb->isChecked());
 }
 
 QString KfindTabWidget::date2String(const QDate & date) {
@@ -534,7 +541,7 @@ QValidator::State KDigitValidator::validate( QString & input, int & ) const
 }
 
 //*******************************************************
-//             Static utility functions	
+//             Static utility functions
 //*******************************************************
 static void save_pattern(QComboBox *obj,
 			 const QString & group, const QString & entry)
