@@ -54,6 +54,6 @@ public:
     QString Autocont;
     QString Formlines;
 
-    Data operator=(Data data);
+    void operator=(Data data);
 };
 #endif 
